==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/PnsCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Collection of Notification Hub or Notification Hub Namespace PNS credentials.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class PnsCredentialsArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs =
        com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PnsCredentialsArgs].
 */
@PulumiTagMarker
public class PnsCredentialsArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("fgayxuldqbkgvwmk")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("tkjcxmbmbvnhbcjd")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("mxgtimjehfxfmovq")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("tbeqatjsbxgaixvi")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("frcakxlrdsmefjhp")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("jfxmceytcrdbheju")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("cpkfbxcuuehwfojy")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("tpjlqwuruslqslxa")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("pooqrkgyeggxtwab")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("ixmwfhejhoxpfvaf")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("oswrtulhtduncmpc")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("qsmhdccmpsabmetr")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("gawhaxbopcehahmh")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("smtmmrduswvpcwpj")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("hguayyprxeabrxxt")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("gtcfmxnffwycypbm")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("xkmabgkdvjpgewsw")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("pirbhbagjpfxbopc")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("fjyjjxrkoyhckihb")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("xlbjvjjcyijepjsf")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("uvecispmpahnhapt")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("gvllvrrymhhfxoik")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("wedbrtlxbnskxjgx")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("ylnulsjdlarqjipr")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): PnsCredentialsArgs = PnsCredentialsArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/PnsCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Collection of Notification Hub or Notification Hub Namespace PNS credentials.
 * @property admCredential Description of a NotificationHub AdmCredential.
 * @property apnsCredential Description of a NotificationHub ApnsCredential.
 * @property baiduCredential Description of a NotificationHub BaiduCredential.
 * @property browserCredential Description of a NotificationHub BrowserCredential.
 * @property gcmCredential Description of a NotificationHub GcmCredential.
 * @property mpnsCredential Description of a NotificationHub MpnsCredential.
 * @property wnsCredential Description of a NotificationHub WnsCredential.
 * @property xiaomiCredential Description of a NotificationHub XiaomiCredential.
 */
public data class PnsCredentialsArgs(
    public val admCredential: Output<AdmCredentialArgs>? = null,
    public val apnsCredential: Output<ApnsCredentialArgs>? = null,
    public val baiduCredential: Output<BaiduCredentialArgs>? = null,
    public val browserCredential: Output<BrowserCredentialArgs>? = null,
    public val gcmCredential: Output<GcmCredentialArgs>? = null,
    public val mpnsCredential: Output<MpnsCredentialArgs>? = null,
    public val wnsCredential: Output<WnsCredentialArgs>? = null,
    public val xiaomiCredential: Output<XiaomiCredentialArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs =
        com.pulumi.azurenative.notificationhubs.inputs.PnsCredentialsArgs.builder()
            .admCredential(admCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .apnsCredential(apnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .baiduCredential(baiduCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .browserCredential(browserCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gcmCredential(gcmCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mpnsCredential(mpnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .wnsCredential(wnsCredential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .xiaomiCredential(
                xiaomiCredential?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PnsCredentialsArgs].
 */
@PulumiTagMarker
public class PnsCredentialsArgsBuilder internal constructor() {
    private var admCredential: Output<AdmCredentialArgs>? = null

    private var apnsCredential: Output<ApnsCredentialArgs>? = null

    private var baiduCredential: Output<BaiduCredentialArgs>? = null

    private var browserCredential: Output<BrowserCredentialArgs>? = null

    private var gcmCredential: Output<GcmCredentialArgs>? = null

    private var mpnsCredential: Output<MpnsCredentialArgs>? = null

    private var wnsCredential: Output<WnsCredentialArgs>? = null

    private var xiaomiCredential: Output<XiaomiCredentialArgs>? = null

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("bvdxadkfthfvgiha")
    public suspend fun admCredential(`value`: Output<AdmCredentialArgs>) {
        this.admCredential = value
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("mwephcfihityoyer")
    public suspend fun apnsCredential(`value`: Output<ApnsCredentialArgs>) {
        this.apnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("oepjylnnwjfwrojy")
    public suspend fun baiduCredential(`value`: Output<BaiduCredentialArgs>) {
        this.baiduCredential = value
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("xxoadwkkrudwvkfc")
    public suspend fun browserCredential(`value`: Output<BrowserCredentialArgs>) {
        this.browserCredential = value
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("jsfjmrdxbgpiwgsn")
    public suspend fun gcmCredential(`value`: Output<GcmCredentialArgs>) {
        this.gcmCredential = value
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("lmowuwhqrtkapiqx")
    public suspend fun mpnsCredential(`value`: Output<MpnsCredentialArgs>) {
        this.mpnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("arknuwmqnjbkbmme")
    public suspend fun wnsCredential(`value`: Output<WnsCredentialArgs>) {
        this.wnsCredential = value
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("gqubyaqqnuvkaoyx")
    public suspend fun xiaomiCredential(`value`: Output<XiaomiCredentialArgs>) {
        this.xiaomiCredential = value
    }

    /**
     * @param value Description of a NotificationHub AdmCredential.
     */
    @JvmName("hwlqypxmjijmbjey")
    public suspend fun admCredential(`value`: AdmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub AdmCredential.
     */
    @JvmName("bfjrasroupjqwbjj")
    public suspend fun admCredential(argument: suspend AdmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = AdmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.admCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub ApnsCredential.
     */
    @JvmName("pqjovexbxmmseapc")
    public suspend fun apnsCredential(`value`: ApnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub ApnsCredential.
     */
    @JvmName("kusqiqxkucdvgigu")
    public suspend fun apnsCredential(argument: suspend ApnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = ApnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BaiduCredential.
     */
    @JvmName("wfeyioianouyujpq")
    public suspend fun baiduCredential(`value`: BaiduCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baiduCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BaiduCredential.
     */
    @JvmName("unxlakdmdbhunyjv")
    public suspend fun baiduCredential(argument: suspend BaiduCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BaiduCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baiduCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub BrowserCredential.
     */
    @JvmName("togwutobrmkmslcn")
    public suspend fun browserCredential(`value`: BrowserCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.browserCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub BrowserCredential.
     */
    @JvmName("scuyvoxypynawjac")
    public suspend fun browserCredential(argument: suspend BrowserCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = BrowserCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.browserCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub GcmCredential.
     */
    @JvmName("elxeccliurtlmmdi")
    public suspend fun gcmCredential(`value`: GcmCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gcmCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub GcmCredential.
     */
    @JvmName("btsrsxmoydoehaql")
    public suspend fun gcmCredential(argument: suspend GcmCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = GcmCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gcmCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub MpnsCredential.
     */
    @JvmName("xktlvqsnsvlmosmq")
    public suspend fun mpnsCredential(`value`: MpnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mpnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub MpnsCredential.
     */
    @JvmName("vseyqbvelqyvuxkp")
    public suspend fun mpnsCredential(argument: suspend MpnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = MpnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.mpnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub WnsCredential.
     */
    @JvmName("melitcywlgoonnbd")
    public suspend fun wnsCredential(`value`: WnsCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.wnsCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub WnsCredential.
     */
    @JvmName("anwpwytrbhtwmtqi")
    public suspend fun wnsCredential(argument: suspend WnsCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = WnsCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.wnsCredential = mapped
    }

    /**
     * @param value Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("rfagdlwrkindqjod")
    public suspend fun xiaomiCredential(`value`: XiaomiCredentialArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.xiaomiCredential = mapped
    }

    /**
     * @param argument Description of a NotificationHub XiaomiCredential.
     */
    @JvmName("otsjuervmsncltbc")
    public suspend fun xiaomiCredential(argument: suspend XiaomiCredentialArgsBuilder.() -> Unit) {
        val toBeMapped = XiaomiCredentialArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.xiaomiCredential = mapped
    }

    internal fun build(): PnsCredentialsArgs = PnsCredentialsArgs(
        admCredential = admCredential,
        apnsCredential = apnsCredential,
        baiduCredential = baiduCredential,
        browserCredential = browserCredential,
        gcmCredential = gcmCredential,
        mpnsCredential = mpnsCredential,
        wnsCredential = wnsCredential,
        xiaomiCredential = xiaomiCredential,
    )
}
